==> istio-model-v1beta1-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingDistributeFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LocalityLoadBalancerSettingDistributeFluentImpl<A extends LocalityLoadBalancerSettingDistributeFluent<A>> extends BaseFluent<A> implements LocalityLoadBalancerSettingDistributeFluent<A>{
  public LocalityLoadBalancerSettingDistributeFluentImpl() {
  }
  public LocalityLoadBalancerSettingDistributeFluentImpl(LocalityLoadBalancerSettingDistribute instance) {
    this.withFrom(instance.getFrom()); 
    this.withTo(instance.getTo()); 
  }
  private String from;
  private Map<String,Long> to;
  public String getFrom() {
    return this.from;
  }
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  public Boolean hasFrom() {
    return this.from != null;
  }
  public A addToTo(String key,Long value) {
    if(this.to == null && key != null && value != null) { this.to = new LinkedHashMap(); }
    if(key != null && value != null) {this.to.put(key, value);} return (A)this;
  }
  public A addToTo(Map<String,Long> map) {
    if(this.to == null && map != null) { this.to = new LinkedHashMap(); }
    if(map != null) { this.to.putAll(map);} return (A)this;
  }
  public A removeFromTo(String key) {
    if(this.to == null) { return (A) this; }
    if(key != null && this.to != null) {this.to.remove(key);} return (A)this;
  }
  public A removeFromTo(Map<String,Long> map) {
    if(this.to == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.to != null){this.to.remove(key);}}} return (A)this;
  }
  public Map<String,Long> getTo() {
    return this.to;
  }
  public <K,V>A withTo(Map<String,Long> to) {
    if (to == null) { this.to =  null;} else {this.to = new LinkedHashMap(to);} return (A) this;
  }
  public Boolean hasTo() {
    return this.to != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LocalityLoadBalancerSettingDistributeFluentImpl that = (LocalityLoadBalancerSettingDistributeFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (to != null ? !to.equals(that.to) :that.to != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (to != null && !to.isEmpty()) { sb.append("to:"); sb.append(to); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingDistributeFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LocalityLoadBalancerSettingDistributeFluentImpl<A extends LocalityLoadBalancerSettingDistributeFluent<A>> extends BaseFluent<A> implements LocalityLoadBalancerSettingDistributeFluent<A>{
  public LocalityLoadBalancerSettingDistributeFluentImpl() {
  }
  public LocalityLoadBalancerSettingDistributeFluentImpl(LocalityLoadBalancerSettingDistribute instance) {
    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
  }
  private String from;
  private Map<String,Long> to;
  public String getFrom() {
    return this.from;
  }
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  public Boolean hasFrom() {
    return this.from != null;
  }
  public A addToTo(String key,Long value) {
    if(this.to == null && key != null && value != null) { this.to = new LinkedHashMap(); }
    if(key != null && value != null) {this.to.put(key, value);} return (A)this;
  }
  public A addToTo(Map<String,Long> map) {
    if(this.to == null && map != null) { this.to = new LinkedHashMap(); }
    if(map != null) { this.to.putAll(map);} return (A)this;
  }
  public A removeFromTo(String key) {
    if(this.to == null) { return (A) this; }
    if(key != null && this.to != null) {this.to.remove(key);} return (A)this;
  }
  public A removeFromTo(Map<String,Long> map) {
    if(this.to == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.to != null){this.to.remove(key);}}} return (A)this;
  }
  public Map<String,Long> getTo() {
    return this.to;
  }
  public <K,V>A withTo(Map<String,Long> to) {
    if (to == null) { this.to =  null;} else {this.to = new LinkedHashMap(to);} return (A) this;
  }
  public Boolean hasTo() {
    return this.to != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LocalityLoadBalancerSettingDistributeFluentImpl that = (LocalityLoadBalancerSettingDistributeFluentImpl) o;
    if (!java.util.Objects.equals(from, that.from)) return false;

    if (!java.util.Objects.equals(to, that.to)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  to,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (to != null && !to.isEmpty()) { sb.append("to:"); sb.append(to); }
    sb.append("}");
    return sb.toString();
  }
  
}
